==> react-form-builder-2.5.0.tgz: package/lib/Input/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";

var _DISPLAY;

import React, { useCallback } from 'react';
import PropTypes from 'prop-types';
import { field, createComponentMemo } from '../prop-types';
import MoleculeInputField from '@s-ui/react-molecule-input-field';
import { FIELDS, DISPLAYS } from '../Standard'; // mapping between DSL standard and HTML input type attribute

var DISPLAY = (_DISPLAY = {}, _DISPLAY[DISPLAYS[FIELDS.TEXT].EMAIL] = 'email', _DISPLAY[DISPLAYS[FIELDS.TEXT].PHONE] = 'tel', _DISPLAY[DISPLAYS[FIELDS.TEXT].NUMERIC] = 'text', _DISPLAY[DISPLAYS[FIELDS.TEXT].TEXT] = 'text', _DISPLAY[DISPLAYS[FIELDS.TEXT].DEFAULT] = 'text', _DISPLAY);
var INPUT_MODES = {
  DECIMAL: 'decimal'
};

var Input = function Input(_ref) {
  var input = _ref.input,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      onBlur = _ref.onBlur,
      size = _ref.size,
      leftAddon = _ref.leftAddon,
      rightAddon = _ref.rightAddon,
      errors = _ref.errors,
      alerts = _ref.alerts;
  var errorMessages = errors[input.id];
  var alertMessages = alerts[input.id];
  var onChangeCallback = useCallback(function (evt) {
    return onChange(input.id, evt.target.value);
  }, [input, onChange]);

  var onBlurCallback = function onBlurCallback() {
    return onBlur(input.id);
  };

  var nextProps = {};

  switch (input.type) {
    case FIELDS.TEXT:
      {
        nextProps = {
          type: DISPLAY[input.display] || 'text'
        }; // this is the html input type (not the field type related to DSL form-builder)

        if (input.display === DISPLAYS[FIELDS.TEXT].NUMERIC) {
          nextProps.inputMode = INPUT_MODES.DECIMAL;
        }

        var constraints = input.constraints || [];
        nextProps = constraints.reduce(function (acc, constraint) {
          var _constraint$property, _constraint$property2, _constraint$property3, _constraint$property4, _constraint$property5, _constraint$property6, _constraint$property7;

          return _extends(_extends(_extends(_extends(_extends({}, acc), (constraint == null ? void 0 : (_constraint$property = constraint.property) == null ? void 0 : _constraint$property.maxlength) && {
            maxLength: constraint == null ? void 0 : (_constraint$property2 = constraint.property) == null ? void 0 : _constraint$property2.maxlength
          }), (constraint == null ? void 0 : (_constraint$property3 = constraint.property) == null ? void 0 : _constraint$property3.minlength) && {
            minLength: constraint == null ? void 0 : (_constraint$property4 = constraint.property) == null ? void 0 : _constraint$property4.minlength
          }), (constraint == null ? void 0 : (_constraint$property5 = constraint.property) == null ? void 0 : _constraint$property5.notnull) === '' && {
            required: true
          }), (constraint == null ? void 0 : (_constraint$property6 = constraint.property) == null ? void 0 : _constraint$property6.pattern) && {
            pattern: constraint == null ? void 0 : (_constraint$property7 = constraint.property) == null ? void 0 : _constraint$property7.pattern
          });
        }, nextProps);
        break;
      }

    case FIELDS.NUMERIC:
      {
        nextProps = {
          type: 'number'
        }; // this is the html type (not the field type related to DSL form-builder)

        var _constraints = input.constraints || [];

        nextProps = _constraints.reduce(function (acc, constraint) {
          var _constraint$property8, _constraint$property9, _constraint$property10, _constraint$property11, _constraint$property12, _constraint$property13, _constraint$property14;

          return _extends(_extends(_extends(_extends(_extends({}, acc), (constraint == null ? void 0 : (_constraint$property8 = constraint.property) == null ? void 0 : _constraint$property8.max) && {
            max: constraint == null ? void 0 : (_constraint$property9 = constraint.property) == null ? void 0 : _constraint$property9.max
          }), (constraint == null ? void 0 : (_constraint$property10 = constraint.property) == null ? void 0 : _constraint$property10.min) && {
            min: constraint == null ? void 0 : (_constraint$property11 = constraint.property) == null ? void 0 : _constraint$property11.min
          }), (constraint == null ? void 0 : (_constraint$property12 = constraint.property) == null ? void 0 : _constraint$property12.notnull) === '' && {
            required: true
          }), (constraint == null ? void 0 : (_constraint$property13 = constraint.property) == null ? void 0 : _constraint$property13.pattern) && {
            pattern: constraint == null ? void 0 : (_constraint$property14 = constraint.property) == null ? void 0 : _constraint$property14.pattern
          });
        }, nextProps);
        break;
      }
  }

  nextProps = _extends(_extends(_extends(_extends(_extends({}, nextProps), input.hidden && {
    hidden: true
  }), input.disabled && {
    disabled: true
  }), !!errorMessages && {
    errorText: errorMessages.join('\n')
  }), !!alertMessages && {
    alertText: alertMessages.join('\n')
  });

  var inputProps = _extends({
    id: input.id,
    name: input.id,
    label: input.label || '',
    tabIndex: tabIndex,
    placeholder: input.hint,
    helpText: input.help,
    value: input.value || '',
    onChange: onChangeCallback,
    onBlur: onBlurCallback,
    size: size,
    leftAddon: leftAddon,
    rightAddon: rightAddon
  }, nextProps);

  if (!nextProps.type) {
    return /*#__PURE__*/React.createElement("span", null, "Unknown Input type ", input.type);
  }

  if (nextProps.hidden) {
    return null;
  }

  return /*#__PURE__*/React.createElement("div", {
    className: "sui-FormBuilder-field sui-FormBuilder-Input sui-FormBuilder-" + inputProps.id
  }, /*#__PURE__*/React.createElement(MoleculeInputField, inputProps));
};

Input.displayName = 'Input';
export default React.memo(Input, createComponentMemo('input'));

==> react-form-builder-3.2.0.tgz: package/lib/Input/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";

var _DISPLAY;

import React, { useCallback } from 'react';
import PropTypes from 'prop-types';
import { field, createComponentMemo } from '../prop-types';
import MoleculeInputField from '@s-ui/react-molecule-input-field';
import { FIELDS, DISPLAYS } from '../Standard'; // mapping between DSL standard and HTML input type attribute

var DISPLAY = (_DISPLAY = {}, _DISPLAY[DISPLAYS[FIELDS.TEXT].EMAIL] = 'email', _DISPLAY[DISPLAYS[FIELDS.TEXT].PHONE] = 'tel', _DISPLAY[DISPLAYS[FIELDS.TEXT].NUMERIC] = 'text', _DISPLAY[DISPLAYS[FIELDS.TEXT].TEXT] = 'text', _DISPLAY[DISPLAYS[FIELDS.TEXT].DEFAULT] = 'text', _DISPLAY);
var INPUT_MODES = {
  DECIMAL: 'decimal'
};

var Input = function Input(_ref) {
  var input = _ref.input,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      onBlur = _ref.onBlur,
      size = _ref.size,
      leftAddon = _ref.leftAddon,
      rightAddon = _ref.rightAddon,
      errors = _ref.errors,
      alerts = _ref.alerts,
      renderer = _ref.renderer;
  var errorMessages = errors[input.id];
  var alertMessages = alerts[input.id];
  var onChangeCallback = useCallback(function (evt) {
    return onChange(input.id, evt.target.value);
  }, [input, onChange]);

  var onBlurCallback = function onBlurCallback() {
    return onBlur(input.id);
  };

  var nextProps = {};

  switch (input.type) {
    case FIELDS.TEXT:
      {
        nextProps = {
          type: DISPLAY[input.display] || 'text'
        }; // this is the html input type (not the field type related to DSL form-builder)

        if (input.display === DISPLAYS[FIELDS.TEXT].NUMERIC) {
          nextProps.inputMode = INPUT_MODES.DECIMAL;
        }

        var constraints = input.constraints || [];
        nextProps = constraints.reduce(function (acc, constraint) {
          var _constraint$property, _constraint$property2, _constraint$property3, _constraint$property4, _constraint$property5, _constraint$property6, _constraint$property7;

          return _extends(_extends(_extends(_extends(_extends({}, acc), (constraint == null ? void 0 : (_constraint$property = constraint.property) == null ? void 0 : _constraint$property.maxlength) && {
            maxLength: constraint == null ? void 0 : (_constraint$property2 = constraint.property) == null ? void 0 : _constraint$property2.maxlength
          }), (constraint == null ? void 0 : (_constraint$property3 = constraint.property) == null ? void 0 : _constraint$property3.minlength) && {
            minLength: constraint == null ? void 0 : (_constraint$property4 = constraint.property) == null ? void 0 : _constraint$property4.minlength
          }), (constraint == null ? void 0 : (_constraint$property5 = constraint.property) == null ? void 0 : _constraint$property5.notnull) === '' && {
            required: true
          }), (constraint == null ? void 0 : (_constraint$property6 = constraint.property) == null ? void 0 : _constraint$property6.pattern) && {
            pattern: constraint == null ? void 0 : (_constraint$property7 = constraint.property) == null ? void 0 : _constraint$property7.pattern
          });
        }, nextProps);
        break;
      }

    case FIELDS.NUMERIC:
      {
        nextProps = {
          type: 'number'
        }; // this is the html type (not the field type related to DSL form-builder)

        var _constraints = input.constraints || [];

        nextProps = _constraints.reduce(function (acc, constraint) {
          var _constraint$property8, _constraint$property9, _constraint$property10, _constraint$property11, _constraint$property12, _constraint$property13, _constraint$property14;

          return _extends(_extends(_extends(_extends(_extends({}, acc), (constraint == null ? void 0 : (_constraint$property8 = constraint.property) == null ? void 0 : _constraint$property8.max) && {
            max: constraint == null ? void 0 : (_constraint$property9 = constraint.property) == null ? void 0 : _constraint$property9.max
          }), (constraint == null ? void 0 : (_constraint$property10 = constraint.property) == null ? void 0 : _constraint$property10.min) && {
            min: constraint == null ? void 0 : (_constraint$property11 = constraint.property) == null ? void 0 : _constraint$property11.min
          }), (constraint == null ? void 0 : (_constraint$property12 = constraint.property) == null ? void 0 : _constraint$property12.notnull) === '' && {
            required: true
          }), (constraint == null ? void 0 : (_constraint$property13 = constraint.property) == null ? void 0 : _constraint$property13.pattern) && {
            pattern: constraint == null ? void 0 : (_constraint$property14 = constraint.property) == null ? void 0 : _constraint$property14.pattern
          });
        }, nextProps);
        break;
      }
  }

  nextProps = _extends(_extends(_extends(_extends(_extends({}, nextProps), input.hidden && {
    hidden: true
  }), input.disabled && {
    disabled: true
  }), !!errorMessages && {
    errorText: errorMessages.join('\n')
  }), !!alertMessages && {
    alertText: alertMessages.join('\n')
  });

  var inputProps = _extends({
    id: input.id,
    name: input.id,
    label: input.label || '',
    tabIndex: tabIndex,
    placeholder: input.hint,
    helpText: input.help,
    value: input.value || '',
    onChange: onChangeCallback,
    onBlur: onBlurCallback,
    size: size,
    leftAddon: leftAddon,
    rightAddon: rightAddon
  }, nextProps);

  if (!nextProps.type) {
    return /*#__PURE__*/React.createElement("span", null, "Unknown Input type ", input.type);
  }

  if (nextProps.hidden) {
    return null;
  }

  var rendererResponse = renderer({
    id: input.id,
    innerProps: inputProps
  }); // render custom component

  if (React.isValidElement(rendererResponse)) return rendererResponse; // render SUI component

  return /*#__PURE__*/React.createElement("div", {
    className: "sui-FormBuilder-field sui-FormBuilder-Input sui-FormBuilder-" + inputProps.id
  }, /*#__PURE__*/React.createElement(MoleculeInputField, Object.assign({}, inputProps, rendererResponse)));
};

Input.displayName = 'Input';
export default React.memo(Input, createComponentMemo('input'));
